pub struct RsyncMessage {
pub connect: PortRef<Connect>,
pub result: PortRef<Result<RsyncResult, String>>,
pub workspace: WorkspaceLocation,
}Fields
connect: PortRef<Connect>The connect message to create a duplex bytestream with the client.
result: PortRef<Result<RsyncResult, String>>A port to send back the rsync result or any errors.
workspace: WorkspaceLocationThe location of the workspace to sync.